<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Services.Maps.OfflineMaps

Windows Runtime (WinRT) APIs for for the `Windows.Services.Maps.OfflineMaps` namespace.

This package provides the `winrt.windows.services.maps.offlinemaps` module.
